rpms/openoffice.org/devel workspace.cmcfixes64.patch, NONE, 1.1 workspace.cmcfixes75.patch, NONE, 1.1 openoffice.org.spec, 1.2227, 1.2228

Caolan McNamara caolanm at fedoraproject.org
Mon May 31 13:16:33 UTC 2010


Author: caolanm

Update of /cvs/pkgs/rpms/openoffice.org/devel
In directory cvs01.phx2.fedoraproject.org:/tmp/cvs-serv3530/devel

Modified Files:
	openoffice.org.spec 
Added Files:
	workspace.cmcfixes64.patch workspace.cmcfixes75.patch 
Log Message:
Resolves: rhbz#598052 workspace.cmcfixes75.patch

workspace.cmcfixes64.patch:
 vtablefactory.cxx |   10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

--- NEW FILE workspace.cmcfixes64.patch ---
diff -r 28ba3ecf6c22 -r db44de918518 bridges/source/cpp_uno/shared/vtablefactory.cxx
--- a/bridges/source/cpp_uno/shared/vtablefactory.cxx	Mon Oct 12 09:26:03 2009 +0000
+++ b/bridges/source/cpp_uno/shared/vtablefactory.cxx	Mon Oct 12 13:29:25 2009 +0000
@@ -272,7 +272,7 @@
         char *tmpfname = new char[aTmpName.getLength()+1];
         strncpy(tmpfname, aTmpName.getStr(), aTmpName.getLength()+1);
         if ((block.fd = mkstemp(tmpfname)) == -1)
-          perror("creation of executable memory area failed");
+            perror("creation of executable memory area failed");
         if (block.fd == -1)
         {
             delete[] tmpfname;
@@ -280,7 +280,13 @@
         }
         unlink(tmpfname);
         delete[] tmpfname;
-        ftruncate(block.fd, block.size);
+        if (ftruncate(block.fd, block.size) == -1)
+        {
+            perror("truncation of executable memory area failed");
+            close(block.fd);
+            block.fd = -1;
+            break;
+        }
         block.start = mmap(NULL, block.size, PROT_READ | PROT_WRITE, MAP_SHARED, block.fd, 0);
         if (block.start== MAP_FAILED) {
             block.start = 0;

workspace.cmcfixes75.patch:
 gnome-open-url.sh |    4 ++--
 open-url.sh       |   54 ++++++++++++++++++++++++++++++++----------------------
 2 files changed, 34 insertions(+), 24 deletions(-)

--- NEW FILE workspace.cmcfixes75.patch ---
diff -r aa9d07722b0e shell/source/unix/misc/open-url.sh
--- a/shell/source/unix/misc/open-url.sh	Wed May 26 13:23:31 2010 +0100
+++ b/shell/source/unix/misc/open-url.sh	Mon May 31 14:10:43 2010 +0100
@@ -46,38 +46,48 @@
 
 # special handling for mailto: uris
 if echo $1 | grep '^mailto:' > /dev/null; then
+  # check for xdg-email
+  mailer=`which xdg-email`
+  if [ ! -z "$mailer" ]; then
+    $mailer "$1" &
+    exit 0
+  fi
   # check $MAILER variable
   if [ ! -z "$MAILER" ]; then
     $MAILER "$1" &
     exit 0
-  else
-    # mozilla derivates may need -remote semantics
-    for i in thunderbird mozilla netscape; do
-      mailer=`which $i`
-      if [ ! -z "$mailer" ]; then
-        run_mozilla "$mailer" "$1"
-        exit 0
-      fi
-    done
-    # handle all non mozilla mail clients below
-    # ..
   fi
+  # mozilla derivates may need -remote semantics
+  for i in thunderbird mozilla netscape; do
+    mailer=`which $i`
+    if [ ! -z "$mailer" ]; then
+      run_mozilla "$mailer" "$1"
+      exit 0
+    fi
+  done
+  # handle all non mozilla mail clients below
+  # ..
 else
+  # check for xdg-open
+  browser=`which xdg-open`
+  if [ ! -z "$browser" ]; then
+    $browser "$1" &
+    exit 0
+  fi
   # check $BROWSER variable
   if [ ! -z "$BROWSER" ]; then
     $BROWSER "$1" &
     exit 0
-  else
-    # mozilla derivates may need -remote semantics
-    for i in firefox mozilla netscape; do
-      browser=`which $i`
-      if [ ! -z "$browser" ]; then
-        run_mozilla "$browser" "$1"
-        exit 0
-      fi
-    done
-    # handle all non mozilla browers below
-    # ..
   fi
+  # mozilla derivates may need -remote semantics
+  for i in firefox mozilla netscape; do
+    browser=`which $i`
+    if [ ! -z "$browser" ]; then
+      run_mozilla "$browser" "$1"
+      exit 0
+    fi
+  done
+  # handle all non mozilla browers below
+  # ..
 fi
 exit 1


Index: openoffice.org.spec
===================================================================
RCS file: /cvs/pkgs/rpms/openoffice.org/devel/openoffice.org.spec,v
retrieving revision 1.2227
retrieving revision 1.2228
diff -u -p -r1.2227 -r1.2228
--- openoffice.org.spec	27 May 2010 19:49:02 -0000	1.2227
+++ openoffice.org.spec	31 May 2010 13:16:32 -0000	1.2228
@@ -1,6 +1,6 @@
 %define oootag OOO320
 %define ooomilestone 19
-%define rh_rpm_release 2
+%define rh_rpm_release 4
 
 # rhbz#465664 jar-repacking breaks help by reordering META-INF/MANIFEST.MF
 %define __jar_repack %{nil}
@@ -140,6 +140,8 @@ Patch69: openoffice.org-3.3.0.ooo111758.
 Patch70: workspace.extras330.patch
 Patch71: openoffice.org-3.2.0.ooo111741.extras.malformed-xml-file.patch
 Patch72: openoffice.org-3.2.0.ooo111886.sw.layout.workaround.patch
+Patch73: workspace.cmcfixes64.patch
+Patch74: workspace.cmcfixes75.patch
 
 %{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
 %define instdir %{_libdir}
@@ -1693,6 +1695,8 @@ cp -p %{SOURCE5} external/unowinreg/unow
 %patch70 -p1 -b .workspace.extras330.patch
 %patch71 -p1 -b .ooo111741.extras.malformed-xml-file.patch
 %patch72 -p0 -b .ooo111886.sw.layout.workaround.patch
+%patch73 -p1 -b .workspace.cmcfixes64.patch
+%patch74 -p1 -b .workspace.cmcfixes75.patch
 
 %build
 echo build start time is `date`, diskspace: `df -h . | tail -n 1`
@@ -4177,6 +4181,12 @@ fi
 %endif
 
 %changelog
+* Mon May 31 2010 Caolán McNamara <caolanm at redhat.com> - 1:3.2.1-19.4
+- Resolves: rhbz#598052 workspace.cmcfixes75.patch
+
+* Fri May 28 2010 Caolán McNamara <caolanm at redhat.com> - 1:3.2.1-19.3
+- protect against broken samba servers
+
 * Thu May 27 2010 Caolán McNamara <caolanm at redhat.com> - 1:3.2.1-19.2
 - Resolves: rhbz#596807 openoffice.org-3.2.0.ooo111886.sw.layout.workaround.patch
 



More information about the scm-commits mailing list
diff -r aa9d07722b0e shell/source/unix/misc/gnome-open-url.sh
--- a/shell/source/unix/misc/gnome-open-url.sh	Wed May 26 13:23:31 2010 +0100
+++ b/shell/source/unix/misc/gnome-open-url.sh	Mon May 31 14:10:43 2010 +0100
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# use gnome-open utility coming with libgnome if available
-gnome-open "$1" 2>/dev/null || "$0.bin" $1
+# use xdg-open or gnome-open if available
+xdg-open "$1" 2>/dev/null || gnome-open "$1" 2>/dev/null || "$0.bin" $1
 
 exit 0